@@ -20,7 +20,6 @@ import sys
 import warnings
 from h2o.frame import H2OFrame
 from h2o.utils.typechecks import assert_is_type, Enum
-from pyspark.ml.util import _jvm
 from pyspark.rdd import RDD
 from pyspark.sql.dataframe import DataFrame
 from pyspark.sql.types import *
@@ -79,9 +78,8 @@ class H2OContext(object):
         # and call SparkSession.builder.getOrCreate on Java side creates a new session, which is not
         # desirable
         activeSession = SparkSession._instantiatedSession
-        if activeSession is not None:
-            jvm = activeSession.sparkContext._jvm
-            jvm.org.apache.spark.sql.SparkSession.setDefaultSession(activeSession._jsparkSession)
+        jvm = activeSession.sparkContext._jvm
+        jvm.org.apache.spark.sql.SparkSession.setDefaultSession(activeSession._jsparkSession)
 
         if spark is not None and isinstance(spark, H2OConf):
             selected_conf = spark
@@ -94,7 +92,8 @@ class H2OContext(object):
         h2o_context = H2OContext()
 
         # Create backing H2OContext
-        package = getattr(_jvm().org.apache.spark.h2o, "H2OContext$")
+        h2o_context._jvm = jvm
+        package = getattr(jvm.org.apache.spark.h2o, "H2OContext$")
         module = package.__getattr__("MODULE$")
         jhc = module.getOrCreate(selected_conf._jconf)
         h2o_context._jhc = jhc
@@ -156,6 +155,12 @@ class H2OContext(object):
     def getConf(self):
         return self._conf
 
+    def setH2OLogLevel(self, level):
+        self._jhc.setH2OLogLevel(level)
+
+    def getH2OLogLevel(self):
+        return self._jhc.getH2OLogLevel()
+
     def asSparkFrame(self, h2oFrame, copyMetadata=True):
         """
         Transforms given H2OFrame to Spark DataFrame
@@ -172,7 +177,7 @@ class H2OContext(object):
 
         if isinstance(h2oFrame, H2OFrame):
             frame_id = h2oFrame.frame_id
-            jdf = self._jhc.asDataFrame(frame_id, copyMetadata)
+            jdf = self._jhc.asSparkFrame(frame_id, copyMetadata)
             sqlContext = SparkSession.builder.getOrCreate()._wrapped
             df = DataFrame(jdf, sqlContext)
             # Attach h2o_frame to dataframe which forces python not to delete the frame when we leave the scope of this
@@ -199,7 +204,7 @@ class H2OContext(object):
             """
         assert_is_type(sparkFrame, DataFrame, RDD)
 
-        df = H2OContext.__prepareSparkDataForConversion(sparkFrame)
+        df = H2OContext.__prepareSparkDataForConversion(self._jvm, sparkFrame)
         if h2oFrameName is None:
             key = self._jhc.asH2OFrameKeyString(df._jdf)
         else:
@@ -207,7 +212,7 @@ class H2OContext(object):
         return H2OFrame.get_frame(key, full_cols=fullCols, light=True)
 
     @staticmethod
-    def __prepareSparkDataForConversion(sparkData):
+    def __prepareSparkDataForConversion(_jvm, sparkData):
         if isinstance(sparkData, DataFrame):
             return sparkData
         elif sparkData.isEmpty():
@@ -221,9 +226,9 @@ class H2OContext(object):
                 elif isinstance(first, bool):
                     return session.createDataFrame(sparkData, BooleanType())
                 elif (isinstance(sparkData.min(), numbers.Integral) and isinstance(sparkData.max(), numbers.Integral)):
-                    if sparkData.min() >= _jvm().Integer.MIN_VALUE and sparkData.max() <= _jvm().Integer.MAX_VALUE:
+                    if sparkData.min() >= _jvm.Integer.MIN_VALUE and sparkData.max() <= _jvm.Integer.MAX_VALUE:
                         return session.createDataFrame(sparkData, IntegerType())
-                    elif sparkData.min() >= _jvm().Long.MIN_VALUE and sparkData.max() <= _jvm().Long.MAX_VALUE:
+                    elif sparkData.min() >= _jvm.Long.MIN_VALUE and sparkData.max() <= _jvm.Long.MAX_VALUE:
                         return session.createDataFrame(sparkData, LongType())
                     else:
                         warnings.warn(
