@@ -35,7 +35,6 @@ class H2ODRF(H2ODRFParams, H2OTreeBasedSupervisedAlgoBase):
                  nbinsCats=1024,
                  minSplitImprovement=1e-5,
                  histogramType="AUTO",
-                 r2Stopping=Utils.javaDoubleMaxValue,
                  nbinsTopLevel=1 << 10,
                  buildTreeOneNode=False,
                  scoreTreeInterval=0,
@@ -66,7 +65,9 @@ class H2ODRF(H2ODRFParams, H2OTreeBasedSupervisedAlgoBase):
                  namedMojoOutputColumns=True,
                  stoppingRounds=0,
                  stoppingMetric="AUTO",
-                 stoppingTolerance=0.001):
+                 stoppingTolerance=0.001,
+                 gainsliftBins=-1,
+                 withContributions=False):
         Initializer.load_sparkling_jar()
         super(H2ODRF, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2ODRF", self.uid)
